@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls - support classes for LDAP controls
 
@@ -6,22 +6,18 @@ The ldap0.controls module provides LDAPControl classes.
 Each class provides support for a certain control.
 """
 
+import inspect
+from importlib import import_module
 from typing import Dict, Optional, Sequence, Tuple
 
-from pyasn1.error import PyAsn1Error
-
 import _libldap0
 
 
 __all__ = [
-    'KNOWN_RESPONSE_CONTROLS',
     # Classes
     'LDAPControl',
     'RequestControl',
     'ResponseControl',
-    # Functions
-    'encode_request_ctrls',
-    'decode_response_ctrls',
 ]
 
 
@@ -108,65 +104,6 @@ class LDAPControl(RequestControl, ResponseControl):
         )
 
 
-def encode_request_ctrls(
-        ctrls: Sequence[RequestControl]
-    ) -> Tuple[str, bool, bytes]:
-    """
-    Return list of readily encoded 3-tuples which can be directly
-    passed to C module _ldap
-
-    ctrls
-        sequence-type of RequestControl objects
-    """
-    if ctrls is None:
-        return None
-    return [
-        (c.controlType.encode('ascii'), c.criticality, c.encode())
-        for c in ctrls
-    ]
-    # end of encode_request_ctrls()
-
-
-def decode_response_ctrls(
-        ctrls: Sequence[ResponseControl],
-        ctrl_reg: Optional[Dict[str, ResponseControl]] = None,
-    ):
-    """
-    Returns list of readily decoded ResponseControl objects
-
-    ctrls
-        Sequence-type of 3-tuples returned by _libldap0.result() containing
-        the encoded ASN.1 control values of response controls.
-    ctrl_reg
-        Dictionary mapping extended control's OID to ResponseControl class
-        of response controls known by the application. If None
-        ldap0.controls.KNOWN_RESPONSE_CONTROLS is used here.
-    """
-    if ctrl_reg is None:
-        ctrl_reg = KNOWN_RESPONSE_CONTROLS
-    result = []
-    for ctrl_type, ctrl_criticality, ctrl_val in ctrls or []:
-        ctrl_type = ctrl_type.decode('ascii')
-        try:
-            control_class = ctrl_reg.get(ctrl_type)
-        except KeyError:
-            if ctrl_criticality:
-                raise _libldap0.UNAVAILABLE_CRITICAL_EXTENSION(
-                    'Unknown critical response control, ctrl_type %r' % (ctrl_type)
-                )
-        else:
-            control = control_class(criticality=ctrl_criticality)
-            try:
-                control.decode(ctrl_val)
-            except PyAsn1Error as err:
-                if ctrl_criticality:
-                    raise err
-            else:
-                result.append(control)
-    return result
-    # end of decode_response_ctrls()
-
-
 class ControlRegistry:
     """
     A simple registry for extended controls and their handler class
@@ -174,15 +111,40 @@ class ControlRegistry:
 
     cmap: Dict[str, ResponseControl]
 
-    def __init__(self):
-        self.cmap = {}
+    def __init__(self, *module_names):
+        self.cmap = None
+        self._module_names = module_names
 
-    def reg(self, control_class):
-        self.cmap[control_class.controlType] = control_class
+    def _reg(self, *module_names):
+        for module_name in module_names:
+            module = import_module(module_name)
+            for _, cls in inspect.getmembers(module, inspect.isclass):
+                if (
+                        issubclass(cls, ResponseControl)
+                        and hasattr(cls, 'controlType')
+                        and cls.controlType is not None
+                    ):
+                    self.cmap[cls.controlType] = cls
 
     def get(self, control_type):
+        if self.cmap is None:
+            self.cmap = {}
+            self._reg(*self._module_names)
         return self.cmap[control_type]
 
-
 # response control OID to class registry
-KNOWN_RESPONSE_CONTROLS = ControlRegistry()
+KNOWN_RESPONSE_CONTROLS = ControlRegistry(
+    __name__+'.deref',
+    __name__+'.libldap',
+    __name__+'.openldap',
+    __name__+'.pagedresults',
+    __name__+'.ppolicy',
+    __name__+'.psearch',
+    __name__+'.pwdpolicy',
+    __name__+'.readentry',
+    __name__+'.sessiontrack',
+    __name__+'.simple',
+    __name__+'.sss',
+    __name__+'.syncrepl',
+    __name__+'.vlv',
+)
