@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.sss - classes for Server Side Sorting
 (see RFC 2891)
@@ -7,7 +7,7 @@ ldap0.controls.sss - classes for Server Side Sorting
 from pyasn1.type import univ, namedtype, tag, namedval, constraint
 from pyasn1.codec.ber import encoder, decoder
 
-from . import RequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import RequestControl, ResponseControl
 
 
 __all__ = [
@@ -136,5 +136,3 @@ class SSSResponseControl(ResponseControl):
             self.attributeType = attribute_type
         else:
             self.attributeType = None
-
-KNOWN_RESPONSE_CONTROLS.reg(SSSResponseControl)
