@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.vlv - classes for Virtual List View
 (see draft-ietf-ldapext-ldapv3-vlv)
@@ -7,7 +7,7 @@ ldap0.controls.vlv - classes for Virtual List View
 from pyasn1.type import univ, namedtype, tag, namedval
 from pyasn1.codec.ber import encoder, decoder
 
-from . import RequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import RequestControl, ResponseControl
 
 
 __all__ = [
@@ -92,8 +92,6 @@ class VLVRequestControl(RequestControl):
         vlv.setComponentByName('target', target)
         return encoder.encode(vlv)
 
-KNOWN_RESPONSE_CONTROLS.reg(VLVRequestControl)
-
 
 class VirtualListViewResultType(univ.Enumerated):
     namedValues = namedval.NamedValues(
@@ -140,5 +138,3 @@ class VLVResponseControl(ResponseControl):
             self.contextID = bytes(context_id)
         else:
             self.contextID = None
-
-KNOWN_RESPONSE_CONTROLS.reg(VLVResponseControl)
