@@ -1,10 +1,10 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.pwdpolicy - classes for Password Policy controls
 (see https://tools.ietf.org/html/draft-vchu-ldap-pwd-policy)
 """
 
-from . import ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import ResponseControl
 
 __all__ = [
     'PasswordExpiringControl',
@@ -21,8 +21,6 @@ class PasswordExpiringControl(ResponseControl):
     def decode(self, encodedControlValue: bytes):
         self.gracePeriod = int(encodedControlValue)
 
-KNOWN_RESPONSE_CONTROLS.reg(PasswordExpiringControl)
-
 
 class PasswordExpiredControl(ResponseControl):
     """
@@ -32,5 +30,3 @@ class PasswordExpiredControl(ResponseControl):
 
     def decode(self, encodedControlValue: bytes):
         self.passwordExpired = (encodedControlValue == b'0')
-
-KNOWN_RESPONSE_CONTROLS.reg(PasswordExpiredControl)
