@@ -4,10 +4,12 @@ ldap0.msad - proprietary stuff for MS Actiev Directory
 """
 
 import struct
+import uuid
 
 __all__ = [
     'sid2sddl',
     'sddl2sid',
+    'ObjectGUID',
 ]
 
 
