@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.openldap - classes for OpenLDAP-specific controls
 """
@@ -6,7 +6,7 @@ ldap0.controls.openldap - classes for OpenLDAP-specific controls
 from pyasn1.type import univ
 from pyasn1.codec.ber import decoder
 
-from . import ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import ResponseControl
 from .simple import ValueLessRequestControl
 
 __all__ = [
@@ -34,5 +34,3 @@ class SearchNoOpControl(ValueLessRequestControl, ResponseControl):
         self.resultCode = int(decodedValue[0])
         self.numSearchResults = int(decodedValue[1])
         self.numSearchContinuations = int(decodedValue[2])
-
-KNOWN_RESPONSE_CONTROLS.reg(SearchNoOpControl)
