@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.pagedresults - classes for Simple Paged control
 (see RFC 2696)
@@ -9,7 +9,7 @@ from pyasn1.type import namedtype, univ
 from pyasn1.codec.ber import encoder, decoder
 from pyasn1_modules.rfc2251 import LDAPString
 
-from . import RequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import RequestControl, ResponseControl
 
 
 __all__ = [
@@ -43,5 +43,3 @@ class SimplePagedResultsControl(RequestControl, ResponseControl):
         )
         self.size = int(decodedValue.getComponentByName('size'))
         self.cookie = decodedValue.getComponentByName('cookie')
-
-KNOWN_RESPONSE_CONTROLS.reg(SimplePagedResultsControl)
