@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.psearch - classes for Persistent Search Control
 (see https://tools.ietf.org/html/draft-ietf-ldapext-psearch)
@@ -11,7 +11,7 @@ from pyasn1.type import namedtype, namedval, univ, constraint
 from pyasn1.codec.ber import encoder, decoder
 from pyasn1_modules.rfc2251 import LDAPDN
 
-from . import RequestControl, ResponseControl, KNOWN_RESPONSE_CONTROLS
+from . import RequestControl, ResponseControl
 
 __all__ = [
     'PersistentSearchControl',
@@ -157,5 +157,3 @@ class EntryChangeNotificationControl(ResponseControl):
         else:
             self.changeNumber = None
         return (self.changeType, self.previousDN, self.changeNumber)
-
-KNOWN_RESPONSE_CONTROLS.reg(EntryChangeNotificationControl)
