@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.readentry - classes for the Read Entry controls
 (see RFC 4527)
@@ -13,7 +13,7 @@ from pyasn1_modules.rfc2251 import LDAPDN, PartialAttributeList
 
 from ..base import encode_list
 from ..res import SearchResultEntry as LDAPResultSearchResultEntry
-from . import LDAPControl, KNOWN_RESPONSE_CONTROLS
+from . import LDAPControl
 
 
 class OpenLDAPITS6899SearchResultEntry(univ.Sequence):
@@ -81,13 +81,9 @@ class PreReadControl(ReadEntryControl):
     """
     controlType: str = '1.3.6.1.1.13.1'
 
-KNOWN_RESPONSE_CONTROLS.reg(PreReadControl)
-
 
 class PostReadControl(ReadEntryControl):
     """
     Class for post-read control described in RFC 4527
     """
     controlType: str = '1.3.6.1.1.13.2'
-
-KNOWN_RESPONSE_CONTROLS.reg(PostReadControl)
