@@ -1,11 +1,11 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.controls.simple - classes for some very simple LDAP controls
 """
 
 import struct
 
-from . import RequestControl, ResponseControl, LDAPControl, KNOWN_RESPONSE_CONTROLS
+from . import RequestControl, ResponseControl, LDAPControl
 
 
 __all__ = [
@@ -111,8 +111,6 @@ class ManageDSAITControl(ValueLessRequestControl):
             criticality=criticality,
         )
 
-KNOWN_RESPONSE_CONTROLS.reg(ManageDSAITControl)
-
 
 class RelaxRulesControl(ValueLessRequestControl):
     """
@@ -126,8 +124,6 @@ class RelaxRulesControl(ValueLessRequestControl):
             criticality=criticality,
         )
 
-KNOWN_RESPONSE_CONTROLS.reg(RelaxRulesControl)
-
 
 class ProxyAuthzControl(RequestControl):
     """
@@ -174,8 +170,6 @@ class AuthorizationIdentityResponseControl(ResponseControl):
     def decode(self, encodedControlValue: bytes):
         self.authzId = encodedControlValue
 
-KNOWN_RESPONSE_CONTROLS.reg(AuthorizationIdentityResponseControl)
-
 
 class SubentriesControl(BooleanControl):
     """
