@@ -640,8 +640,11 @@ class LDAPObject:
             except _libldap0.NO_SUCH_OBJECT:
                 old_dn = None
             else:
-                old_dn = dn
-                old_entry = old_res.entry_as
+                if old_res is None:
+                    old_dn = None
+                else:
+                    old_dn = dn
+                    old_entry = old_res.entry_as
         else:
             # forced to search for the old entry
             if old_base is None:
@@ -1041,7 +1044,7 @@ class LDAPObject:
             req_ctrls=req_ctrls,
         )
         if wai.responseValue and wai.responseValue.lower().startswith('dn:'):
-            # cache this for later calls to get_whoami_dn()
+            # cache this for later calls to .whoami_s()
             self._whoami_dn = wai.responseValue[3:]
         return wai.responseValue
 
