@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.schema.parse - Low-level parsing functions for schema element strings
 """
@@ -6,16 +6,25 @@ ldap0.schema.parse - Low-level parsing functions for schema element strings
 import re
 
 TOKENS_FINDALL = re.compile(
-    r"(\()"           # opening parenthesis
-    r"|"              # or
-    r"(\))"           # closing parenthesis
-    r"|"              # or
-    r"([^'$()\s]+)"   # string of length >= 1 without '$() or whitespace
-    r"|"              # or
-    r"('.*?'(?!\w))"  # any string or empty string surrounded by single quotes
-                      # except if right quote is succeeded by alphanumeric char
-    r"|"              # or
-    r"([^\s]+?)",     # residue, all non-whitespace strings
+    # opening parenthesis
+    r"(\()"
+    # or
+    r"|"
+    # closing parenthesis
+    r"(\))"
+    # or
+    r"|"
+    # string of length >= 1 without '$() or whitespace
+    r"([^'$()\s]+)"
+    # or
+    r"|"
+    # any string or empty string surrounded by unescaped single quotes
+    # except if right quote is succeeded by alphanumeric char
+    r"('(?:[^'\\]|\\.)*'(?!\w))"
+    # or
+    r"|"
+    # residue, all non-whitespace strings
+    r"([^\s]+?)",
 ).findall
 
 
