@@ -1,4 +1,4 @@
-# -*- coding: utf-8 -*-
+# -*- coding: ascii -*-
 """
 ldap0.test - module for spawning test instances of OpenLDAP's slapd server
 """
@@ -93,8 +93,8 @@ class SlapdObject:
     """
     slapd_conf_template = SLAPD_CONF_TEMPLATE
     database = 'mdb'
-    suffix = 'o=öäü,dc=example,dc=org'
-    root_cn = 'Mänager'
+    suffix = 'o=\xE4\xF6\xFC,dc=example,dc=org'
+    root_cn = 'M\xE4nager'
     root_dn = 'cn=%s,%s' % (root_cn, suffix)
     root_pw = 'password'
     slapd_loglevel = [
